summaryrefslogtreecommitdiffstats
path: root/src/rtfgen.cpp
diff options
context:
space:
mode:
authordimitri <dimitri@afe2bf4a-e733-0410-8a33-86f594647bc7>2002-02-24 18:57:25 (GMT)
committerdimitri <dimitri@afe2bf4a-e733-0410-8a33-86f594647bc7>2002-02-24 18:57:25 (GMT)
commitc7bc295f92f56d1dea369663e058933f550a0187 (patch)
tree81d72027898b1a75221b9ca82b04075277821a9f /src/rtfgen.cpp
parent9793ce49f1d7641854ef0608b34c1dd2d4891a20 (diff)
downloadDoxygen-c7bc295f92f56d1dea369663e058933f550a0187.zip
Doxygen-c7bc295f92f56d1dea369663e058933f550a0187.tar.gz
Doxygen-c7bc295f92f56d1dea369663e058933f550a0187.tar.bz2
Release-1.2.14-20020224
Diffstat (limited to 'src/rtfgen.cpp')
-rw-r--r--src/rtfgen.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rtfgen.cpp b/src/rtfgen.cpp
index d83711a..ac777d6 100644
--- a/src/rtfgen.cpp
+++ b/src/rtfgen.cpp
@@ -2152,14 +2152,14 @@ void RTFGenerator::endClassDiagram(ClassDiagram &d,
{
newParagraph();
// create a gif file
d.writeImage(t,dir,fileName,FALSE);
// display the file
t << "{" << endl;
t << Rtf_Style_Reset << endl;
t << "\\par\\pard \\qc {\\field\\flddirty {\\*\\fldinst INCLUDEPICTURE ";
- t << fileName << ".gif";
+ t << fileName << ".png";
t << " \\\\d \\\\*MERGEFORMAT}{\\fldrslt IMAGE}}\\par" << endl;
t << "}" << endl;
}
@@ -2152,14 +2152,14 @@ void RTFGenerator::endClassDiagram(ClassDiagram &d,
{
newParagraph();
- // create a gif file
+ // create a png file
d.writeImage(t,dir,fileName,FALSE);
// display the file